<?php

defined( 'ABSPATH' ) || exit; // Exit if accessed directly

if( ! class_exists( 'KANEWS_POST_VIEWS' ) ) {

	class KANEWS_POST_VIEWS {

		function __construct() {
      add_filter('cron_schedules', array( $this, 'cron_schedules' ));
      add_filter('switch_theme', array($this, 'clear_schedules'));

      add_action( 'kanews_post_views_daily', array($this, 'clear_daily') );
      if ( !wp_next_scheduled( 'kanews_post_views_daily' ) ) {
        wp_schedule_event( time(), 'kanews_daily', 'kanews_post_views_daily' );
      }

      add_action( 'kanews_post_views_weekly', array($this, 'clear_weekly') );
      if ( !wp_next_scheduled( 'kanews_post_views_weekly' ) ) {
        wp_schedule_event( time(), 'kanews_weekly', 'kanews_post_views_weekly' );
      }

      add_action( 'kanews_post_views_monthly', array($this, 'clear_monthly') );
      if ( !wp_next_scheduled( 'kanews_post_views_monthly' ) ) {
        wp_schedule_event( time(), 'kanews_monthly', 'kanews_post_views_monthly' );
      }
    }

    function clear_schedules() {	
      wp_clear_scheduled_hook( 'kanews_post_views_daily' );
      wp_clear_scheduled_hook( 'kanews_post_views_weekly' );
      wp_clear_scheduled_hook( 'kanews_post_views_monthly' );
    }

    function cron_schedules( $schedules ) {
      $schedules['kanews_daily'] = array(
        'interval' => 86400,
        'display' => __('Günde bir', 'kanews')
      );
      $schedules['kanews_weekly'] = array(
        'interval' => 604800, 
        'display' => __('Haftada bir', 'kanews')
      );
      $schedules['kanews_monthly'] = array(
        'interval' => 2592000,
        'display' => __('Ayda bir', 'kanews')
      );
      return $schedules;
    }

    function clear_daily() {
      $posts = get_posts(array('numberposts' => -1) );
      foreach($posts as $post) {
        update_post_meta($post->ID, 'post_views_count_daily', 0);
      }
    }

    function clear_weekly() {
      $posts = get_posts(array('numberposts' => -1) );
      foreach($posts as $post) {
        update_post_meta($post->ID, 'post_views_count_weekly', 0);
      }
    }

    function clear_monthly() {
      $posts = get_posts(array('numberposts' => -1) );
      foreach($posts as $post) {
        update_post_meta($post->ID, 'post_views_count_monthly', 0);
      }
    }


  }
  
  $KANEWS_POST_VIEWS = new KANEWS_POST_VIEWS();
}

// Set Post Views
if ( ! function_exists( 'kanews_set_post_views') ) {
	function kanews_set_post_views($postID) {

		if (kanews_get_option('post-views') == false)
		return '';

		$count_key  = 'post_views_count';
		$count_key2 = 'post_views_count_daily';
		$count_key3 = 'post_views_count_weekly';
		$count_key4 = 'post_views_count_monthly';

		$count  = get_post_meta($postID, $count_key, true);
		$count2 = get_post_meta($postID, $count_key2, true);
		$count3 = get_post_meta($postID, $count_key3, true);
		$count4 = get_post_meta($postID, $count_key4, true);

		if($count=='') {
			add_post_meta($postID, $count_key, 1);
		} else {
			$count++;
			update_post_meta($postID, $count_key, $count);
		}

		if($count2=='') {
			add_post_meta($postID, $count_key2, 1);
		} else {
			$count2++;
			update_post_meta($postID, $count_key2, $count2);
		}

		if($count3=='') {
			add_post_meta($postID, $count_key3, 1);
		} else {
			$count3++;
			update_post_meta($postID, $count_key3, $count3);
		}

		if($count4=='') {
			add_post_meta($postID, $count_key4, 1);
		} else {
			$count4++;
			update_post_meta($postID, $count_key4, $count4);
		}

	}
}

// Get Post Views Count
if ( ! function_exists( 'kanews_get_post_views') ) {
  function kanews_get_post_views($postID, $time = '', $icon = false, $dropdown = false) {

		if (kanews_get_option('post-views') == false)
    return '';

    if($icon == true)
    $icon = '<i class="icon-view"></i>';
    
    $out = '';
    if($dropdown = false) {
      if($time == 'monthly')
        $out = get_post_meta($postID, 'post_views_count_monthly', true);
      elseif($time == 'weekly')
        $out = get_post_meta($postID, 'post_views_count_weekly', true);
      elseif($time == 'daily')
        $out = get_post_meta($postID, 'post_views_count_daily', true);
      else
        $out = get_post_meta($postID, 'post_views_count', true);
    } else {
      if(has_post_format( 'video', $pid )) {
        $title = esc_html__( 'Ne Kadar İzlendi?', 'kanews' );
      }else {
        $title = kanews_get_option('post-views-dropdown-title') != '' ? kanews_get_option('post-views-dropdown-title') : esc_html__( 'Ne Kadar Okundu?', 'kanews' );
      }
      
      $out .= '<div class="kanews-dropdown">'; 
        $out .= '<div data-toggle="kanews-dropdown-post-views-'.$postID.'" class="kanews-dropdown-item">'.$icon.get_post_meta($postID, 'post_views_count', true).'</div>';
        $out .= '<div id="kanews-dropdown-post-views-'.$postID.'" class="kanews-dropdown-content">';
          $out .= '<ul>';
            $out .= '<li class="kanews-dropdown-title">'.$title.'</li>';
            $out .= '<li>'.esc_html__( 'Bugün', 'kanews' ).' <span>'.get_post_meta($postID, 'post_views_count_daily', true).'</span></li>';
            $out .= '<li>'.esc_html__( 'Bu Hafta', 'kanews' ).' <span>'.get_post_meta($postID, 'post_views_count_weekly', true).'</span></li>';
            $out .= '<li>'.esc_html__( 'Bu Ay', 'kanews' ).' <span>'.get_post_meta($postID, 'post_views_count_monthly', true).'</span></li>';
          $out .= '</ul>';
        $out .= '</div>'; 
      $out .= '</div>'; 
      $icon = '';
    }

    return '<span class="kanews-post-views">'.$icon.$out.'</span>';

  }
}