<?php

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


if( ! class_exists( 'KANEWS_WP_HELPER' ) ) {

	class KANEWS_WP_HELPER {

    // Disable Srcset
    public static function disable_srcset($sources) {
      return false;
    }

    // Cat ID
    public static function primary_category_id($pid) {
      $cat_name = $id = '';
      if (!isset($cat_name) || $cat_name == '') {
        if(get_post_meta($pid, 'kanews_primary_category', true) != '0' && get_post_meta($pid, 'kanews_primary_category', true) != '') {
          $id   = get_post_meta($pid, 'kanews_primary_category', true);
        }
        elseif ( class_exists('WPSEO_Primary_Term') ) {
          $wpseo_primary_term = new WPSEO_Primary_Term( 'category', $pid );
          $wpseo_primary_term = $wpseo_primary_term->get_primary_term();
          $term               = get_term( $wpseo_primary_term );
  
          if (is_wp_error($term)) {
              $categories = get_the_terms($pid, 'category');
              $id 		  	= $categories[0]->term_id;
          } else {
              $cat_name = $term->name;
              $id	   	  = $term->term_id;
          }
  
        } else {
          $categories = get_the_terms($pid, 'category');
          $id			    = $categories[0]->term_id;
        }
      }
  
      return $id;
    }

    // Remove Woocommerce Styles
    public static function woocommerce_styles() {
      if ( ! class_exists( 'WooCommerce' ) ) {
        wp_deregister_script('jquery');
        return;
      }
      remove_action( 'wp_head', array( $GLOBALS['woocommerce'], 'generator' ) );
      if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() ) {
        wp_dequeue_style( 'woocommerce_frontend_styles' );
        wp_dequeue_style( 'woocommerce-general');
        wp_dequeue_style( 'woocommerce-layout' );
        wp_dequeue_style( 'woocommerce-smallscreen' );
        wp_dequeue_style( 'wc-block-style' );
        wp_dequeue_script( 'woocommerce' );
        wp_deregister_script('jquery');
      } else {
        wp_enqueue_script('jquery');
        wp_enqueue_style('kanews-wc-style', get_template_directory_uri() . '/assets/css/wc.css', array(), KAN_THEME_VER);
      }
    }

    // Comments Order Reverse
    public static function comments_order_reverse_parameter() {
      if (!isset($_GET['comments_order']))
      return;

      if ($_GET['comments_order'] == 'asc') {
        add_filter( 'comments_array', function( $comments ) { return array_reverse( $comments ); } );
      }
    }

    public static function excerpt_more( $more ) {
      return '&#46;&#46;&#46;';
    }

    public static function sanitize_pagination($content) {

      $content = preg_replace('#<h2.*?>(.*?)<\/h2>#si', '', $content);
      return $content;
    }

    public static function the_tags($html) {
        $postid = get_the_ID();
        $html = str_replace('<a','<a class="kanews-label kanews-entry-tag"',$html);
        $html = str_replace('rel="tag">','rel="tag"># ',$html);
        return $html;
    }
    
    public static function wp_link_pages($args) {
      global $page, $numpages, $more, $pagenow;

      if (!$args['next_or_number'] == 'next_and_number') 
          return $args; # exit early

      $args['next_or_number'] = 'number'; # keep numbering for the main part
      if (!$more)
          return $args; # exit early
      
          $args['link_before'] = '<span class="classlinks %s">';

      return $args;
    }

    // DNS Prefetch
    public static function dns_prefetch() {
      $option = kanews_get_option('dns-prefetch');
      if ($option != false) {
    
        echo "\n<meta http-equiv='x-dns-prefetch-control' content='on'>\n";
    
        $dns_domains = array(
          "//s.gravatar.com",
          "//www.google-analytics.com"
        );
    
        foreach ( $dns_domains as $domain ) {
          if ( ! empty( $domain ) ){
            echo "<link rel='dns-prefetch' href='$domain' />\n";
          }
        }
      }
    }

    // Weather DNS Prefetch
    public static function weather_dns_prefetch() {
      $option = kanews_get_option('openweathermap-api');
      if(empty($option))
      return false;
      echo "<link rel='dns-prefetch' href='//api.openweathermap.org' />\n";
    }

    // Update Author Nickname
    public static  function update_author_nickname($author) {
      global $comment;
      if (!empty($comment->user_id)){
          $user=get_userdata($comment->user_id);
          $author=$user->display_name;    
      }
  
      return $author;
    }

    public static function cat_posts_per_page($query) {
      if ( is_admin() || ! is_category() || ! $query->is_main_query() || ( isset( $_GET['orderby'] ) && $_GET['orderby'] !== 'date' ))
      return;
      $cid = get_queried_object()->term_id;
      $posts = get_term_meta( $cid, 'category-posts-per-page', true );
      if($posts == '')
      return;
      else
      $query->set( 'posts_per_page', $posts );
    }


  }
  
  $KANEWS_WP_HELPER = new KANEWS_WP_HELPER();
}