<?php

if ( ! defined( 'ABSPATH' ) ) {
	die();
}

// Register Widget
add_action('widgets_init', 'kanews_widget_currencies');
function kanews_widget_currencies() {
	register_widget('kanews_widget_class_currencies');
}

// Widget Class
class kanews_widget_class_currencies extends WP_Widget {

  // Create
	public function __construct(){
		$widget_ops = array('classname' => 'kanews_widget_currencies');
		$control_ops = array('id_base' => 'kanews_widget_currencies');
		parent::__construct('kanews_widget_currencies', ''.KAN_THEME_NAME .' - '.__( "Piyasalar" , 'kanews' ), $widget_ops, $control_ops );
	}
  
  // Front-end
	public function widget($args, $instance)
	{
		extract($args);
    $title = apply_filters('widget_title', $instance['title'] );
    $grid = (!empty($instance['grid'])) ? $instance['grid'] : 'col-12';
    $type = $instance['type'] ? $instance['type'] : 'box';
    $currencies = $instance['currencies'] ? $instance['currencies'] : '';
    $show_change = !isset($instance['show_change']) ? false : true;

    $data = get_option('kanews_currencies');

    if(!$currencies)
    return;

    ?>

    <div class="<?php echo $grid; ?>">
      <div class="kanews-section">
        <?php echo kanews_widget_title($title); ?>
        <?php if($type == 'table'): ?>
          <table class="kanews-table table-currencies">
            <thead>
              <tr>
                <th><span class="nobr"><?php esc_html_e( 'Adı', 'kanews' ); ?></span></th>
                <th style="text-align:right"><span class="nobr"><?php esc_html_e( 'Değer', 'kanews' ); ?></span></th>
                <?php if($show_change == true): ?>
                <th style="text-align:right"><span class="nobr"><?php esc_html_e( 'Değişim', 'kanews' ); ?></span></th>
                <?php endif; ?>
              </tr>
            </thead>
            <tbody>
              <?php foreach($currencies as $currency): 
                if($data->$currency->value == 0)
                $data->$currency->value = number_format((float)$data->$currency->shutdown, 3,",",".");
                if ($data->$currency->change_percent < 0) 
                $class = 'color-danger';
                else 
                $class = 'color-success';
                $change =  $currency->change_percent;
                if ($change < 0) {
                  $icon = '<i class="icon-caret icon-180deg color-danger icon-2x"></i>';
                } else {
                  $icon = '<i class="icon-caret color-success icon-2x"></i>';
                }
                ?>
                <tr>
                  <?php if($data->$currency->full): ?>
                    <td><?php echo $data->$currency->full; ?></td>
                  <?php else: ?>
                    <td><?php echo $data->$currency->name; ?></td>
                  <?php endif; ?>
                  <td style="text-align:right"><?php echo $icon.number_format((float)$data->$currency->value, 3,",",".");?></td>
                  <?php if($show_change == true): ?>
                  <td style="text-align:right" class="<?php echo $class; ?>">%<?php echo $data->$currency->change_percent; ?></td>
                  <?php endif; ?>
                </tr>
              <?php endforeach; ?>
            </tbody>
          </table>
        <?php else: ?>
          <div class="kanews-inline-card">
            <?php foreach($currencies as $currency): 
              if($data->$currency->value == 0)
              $data->$currency->value = number_format((float)$data->$currency->shutdown, 3,",",".");
              if ($data->$currency->change_percent < 0) 
                $class = 'border-danger color-danger';
              else 
                $class = 'border-success color-success';
              ?>
              <div class="kanews-inline-card-item">
                <div class="kanews-inline-card-icon <?php echo $class; ?>"><i class="icon-arrow"></i></div>
                <div class="kanews-inline-card-summary">
                  <div class="kanews-inline-card-title"><?php echo $data->$currency->name; ?></div>
                  <div class="kanews-inline-card-content"><?php echo number_format($data->$currency->value, 3,",",".");?></div>
                </div>
              </div>
            <?php endforeach; ?>
          </div>
          <?php endif; ?>
      </div>
    </div>
  <?php
	}
  
  // Update Form
	public function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];
		$instance['grid'] = $new_instance['grid'];
		$instance['type'] = $new_instance['type'];
		$instance['currencies'] = $new_instance['currencies'];
		$instance['show_change'] = $new_instance['show_change'];
		
		return $instance;
	}

  // Back-end
	public function form($instance)
	{
		$defaults = array( 
      'title' => esc_html__( 'Piyasalar', 'kanews' ), 
			'type' => 'box', 
			'grid' => 'col-12', 
			'show_change' => 'on', 
			'currencies' => array('usd', 'eur', 'gau', 'ise-100', 'btc', 'gbp'), 
    );
		$instance = wp_parse_args((array) $instance, $defaults); ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Başlık' , 'kanews') ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" type="text" />
		</p>

    <p class="kanews-grid-select-x">
			<label for="<?php echo $this->get_field_id('grid'); ?>"><?php _e( 'Genişlik' , 'kanews') ?></label> 
			<select id="<?php echo $this->get_field_id('grid'); ?>" name="<?php echo $this->get_field_name('grid'); ?>" class="widefat" style="width:100%;">
				<option value='col' <?php if ('col' == $instance['grid']) echo 'selected="selected"'; ?>>Sığdır</option>
				<option value='col-12' <?php if ('col-12' == $instance['grid']) echo 'selected="selected"'; ?>>12/12</option>
				<option value='col-12 col-lg-8' <?php if ('col-12 col-lg-8' == $instance['grid']) echo 'selected="selected"'; ?>>12/8</option>
				<option value='col-12 col-lg-6' <?php if ('col-12 col-lg-6' == $instance['grid']) echo 'selected="selected"'; ?>>12/6</option>
				<option value='col-12 col-lg-4' <?php if ('col-12 col-lg-4' == $instance['grid']) echo 'selected="selected"'; ?>>12/4</option>
			</select>
    </p> 

    <p>
			<label for="<?php echo $this->get_field_id('type'); ?>"><?php _e( 'Tür' , 'kanews') ?></label> 
			<select id="<?php echo $this->get_field_id('type'); ?>" name="<?php echo $this->get_field_name('type'); ?>" class="widefat" style="width:100%;">
				<option value='table' <?php if ('table' == $instance['type']) echo 'selected="selected"'; ?>><?php esc_html_e( 'Tablo', 'kanews' ); ?></option>
				<option value='box' <?php if ('box' == $instance['type']) echo 'selected="selected"'; ?>><?php esc_html_e( 'Kutu', 'kanews' ); ?></option>
			</select>
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('currencies'); ?>"><?php _e( 'Gösterilecek Kurlar' ); ?></label><br>
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-usd'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="usd" <?php checked("1", in_array('usd', $instance["currencies"])); ?> /> USD/TRY
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-euro'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="euro" <?php checked("1", in_array('euro', $instance["currencies"])); ?> /> EUR/TRY
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-gbp'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="gbp" <?php checked("1", in_array('gbp', $instance["currencies"])); ?> /> GBP/TRY
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-eur-usd'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="eur-usd" <?php checked("1", in_array('eur-usd', $instance["currencies"])); ?> /> EUR/USD
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-ise-100'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="ise-100" <?php checked("1", in_array('ise-100', $instance["currencies"])); ?> /> Bist 100
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-gau'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="gau" <?php checked("1", in_array('gau', $instance["currencies"])); ?> /> Gram Altın
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-btc'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="btc" <?php checked("1", in_array('btc', $instance["currencies"])); ?> /> Bitcoin
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-ltc'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="ltc" <?php checked("1", in_array('ltc', $instance["currencies"])); ?> /> Litecoin
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-bch'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="bch" <?php checked("1", in_array('bch', $instance["currencies"])); ?> /> Bitcoin Cash
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-eth'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="eth" <?php checked("1", in_array('eth', $instance["currencies"])); ?> /> Ethereum
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-xrp'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="xrp" <?php checked("1", in_array('xrp', $instance["currencies"])); ?> /> XRP
      <input class="checkbox" id="<?php echo $this->get_field_id("currencies") .'-ltc'; ?>" name="<?php echo $this->get_field_name("currencies"); ?>[]" type="checkbox" value="ltc" <?php checked("1", in_array('ltc', $instance["currencies"])); ?> /> Litecoin
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('show_change'); ?>"><?php _e( 'Değişimi Göster' , 'kanews') ?></label>
			<input class="checkbox" type="checkbox" <?php checked($instance['show_change'], 'on'); ?> id="<?php echo $this->get_field_id('show_change'); ?>" name="<?php echo $this->get_field_name('show_change'); ?>" /> 
		</p>

	<?php }
}
?>